Customization
=============
Various customization examples:

- Address provider implementation.
- Band provider implementation.
- Replace built-in fake data corpus/vocabulary with a custom one.
- Override default data.
